-- version 1.2.1

dofile("data/scripts/lib/mod_settings.lua") -- see this file for documentation on some of the features.
local mod_id = "play_last_seed" -- This should match the name of your mod's folder.

function mod_setting_change_callback(mod_id, gui, in_main_menu, setting,
                                     old_value, new_value)
    -- print(tostring(new_value))
end

function seed_setting_callback(mod_id, gui, in_main_menu, setting, old_value,
                               new_value)
    if new_value ~= "" and (tonumber(new_value) > 4294967295) then
        new_value = 4294967295
    end
    if ModSettingGet(mod_id .. ".use_prev_seed") then
        ModSettingSet(mod_id .. ".prev_seed", new_value)
    end
    ModSettingSetNextValue(mod_setting_get_id(mod_id, setting), new_value, false)
    ModSettingSet(mod_setting_get_id(mod_id, setting), new_value)
end

mod_settings_version = 1 -- This is a magic global that can be used to migrate settings to new mod versions. call mod_settings_get_version() before mod_settings_update() to get the old value. 
mod_settings = {
    {
        id = "use_prev_seed",
        ui_name = "Use previous game seed",
        value_default = false,
        scope = MOD_SETTING_SCOPE_RUNTIME,
        change_fn = mod_setting_change_callback
    }, {
        id = "set_seed",
        ui_name = "Previous world seed",
        ui_description = "The world seed from the previous game.",
        value_default = "0",
        scope = MOD_SETTING_SCOPE_RUNTIME,
        text_max_length = 10,
        allowed_characters = "0123456789",
        change_fn = seed_setting_callback
    }
}

-- This function is called to ensure the correct setting values are visible to the game via ModSettingGet(). your mod's settings don't work if you don't have a function like this defined in settings.lua.
-- This function is called:
--		- when entering the mod settings menu (init_scope will be MOD_SETTINGS_SCOPE_ONLY_SET_DEFAULT)
-- 		- before mod initialization when starting a new game (init_scope will be MOD_SETTING_SCOPE_NEW_GAME)
--		- when entering the game after a restart (init_scope will be MOD_SETTING_SCOPE_RESTART)
--		- at the end of an update when mod settings have been changed via ModSettingsSetNextValue() and the game is unpaused (init_scope will be MOD_SETTINGS_SCOPE_RUNTIME)
function ModSettingsUpdate(init_scope)
    local old_version = mod_settings_get_version(mod_id) -- This can be used to migrate some settings between mod versions.
    mod_settings_update(mod_id, mod_settings, init_scope)
end

-- This function should return the number of visible setting UI elements.
-- Your mod's settings wont be visible in the mod settings menu if this function isn't defined correctly.
-- If your mod changes the displayed settings dynamically, you might need to implement custom logic.
-- The value will be used to determine whether or not to display various UI elements that link to mod settings.
-- At the moment it is fine to simply return 0 or 1 in a custom implementation, but we don't guarantee that will be the case in the future.
-- This function is called every frame when in the settings menu.
function ModSettingsGuiCount()
    return mod_settings_gui_count(mod_id, mod_settings)
end

-- This function is called to display the settings UI for this mod. Your mod's settings wont be visible in the mod settings menu if this function isn't defined correctly.
function ModSettingsGui(gui, in_main_menu)
    mod_settings_gui(mod_id, mod_settings, gui, in_main_menu)
end
